# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aa_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


# from validate.v1 import validate_pb2 as validate_dot_v1_dot_validate__pb2
from .validate.v1 import validate_pb2 as validate_dot_v1_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x61\x61_service.proto\x12\raa_service.v1\x1a\x1avalidate/v1/validate.proto\"\x07\n\x05\x45mpty\"\x16\n\x05\x43hunk\x12\r\n\x05\x63hunk\x18\x01 \x01(\x0c\"!\n\x1fGetInventoryHierarchicalRequest\"\xf9\x06\n GetInventoryHierarchicalResponse\x12L\n\tinventory\x18\x01 \x03(\x0b\x32\x39.aa_service.v1.GetInventoryHierarchicalResponse.Datastore\x1a\x66\n\tDatastore\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12?\n\x03\x64\x62s\x18\x03 \x03(\x0b\x32\x32.aa_service.v1.GetInventoryHierarchicalResponse.Db\x1a\xc6\x01\n\x02\x44\x62\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x0c\x64\x61tastore_id\x18\x03 \x01(\t\x12G\n\x07schemas\x18\x04 \x03(\x0b\x32\x36.aa_service.v1.GetInventoryHierarchicalResponse.Schema\x12\x45\n\x06tables\x18\x05 \x03(\x0b\x32\x35.aa_service.v1.GetInventoryHierarchicalResponse.Table\x1a|\n\x06Schema\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x64\x62_path\x18\x03 \x01(\t\x12\x45\n\x06tables\x18\x04 \x03(\x0b\x32\x35.aa_service.v1.GetInventoryHierarchicalResponse.Table\x1a\x92\x01\n\x05Table\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x64\x62_path\x18\x03 \x01(\t\x12\x13\n\x0bschema_path\x18\x04 \x01(\t\x12G\n\x07\x63olumns\x18\x05 \x03(\x0b\x32\x36.aa_service.v1.GetInventoryHierarchicalResponse.Column\x1a\x84\x01\n\x06\x43olumn\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\ntable_path\x18\x03 \x01(\t\x12J\n\x07hstores\x18\x04 \x03(\x0b\x32\x39.aa_service.v1.GetInventoryHierarchicalResponse.SubColumn\x1a<\n\tSubColumn\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x63olumn_path\x18\x03 \x01(\t\"\x19\n\x17GetInventoryFlatRequest\"\x97\x03\n\x18GetInventoryFlatResponse\x12\x41\n\tinventory\x18\x01 \x03(\x0b\x32..aa_service.v1.GetInventoryFlatResponse.Column\x1a\xb7\x02\n\x06\x43olumn\x12\x12\n\ncreated_at\x18\x01 \x01(\x03\x12\x12\n\nupdated_at\x18\x02 \x01(\x03\x12\x14\n\x0c\x64\x61tastore_id\x18\x03 \x01(\t\x12\x16\n\x0e\x64\x61tastore_name\x18\x04 \x01(\t\x12\x0c\n\x04path\x18\x05 \x01(\t\x12\x19\n\x11table_physical_id\x18\x06 \x01(\t\x12\x1e\n\x16table_attribute_number\x18\x07 \x01(\x04\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\r\n\x05\x61lias\x18\t \x01(\t\x12\x12\n\ntable_path\x18\n \x01(\t\x12\x12\n\ndata_label\x18\x0b \x01(\t\x12\x11\n\tdata_type\x18\x0c \x01(\t\x12\x15\n\rdata_type_oid\x18\r \x01(\r\x12\x11\n\tvalidated\x18\x0e \x01(\x08\x12\x0c\n\x04tags\x18\x0f \x03(\t\"h\n\x1dUpdateColumnLockStatusRequest\x12\x1d\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x15\n\x04path\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x11\n\tvalidated\x18\x03 \x01(\x08\" \n\x1eUpdateColumnLockStatusResponse\"h\n\x1cUpdateColumnDataLabelRequest\x12\x1d\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x15\n\x04path\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x12\n\ndata_label\x18\x03 \x01(\t\"\x1f\n\x1dUpdateColumnDataLabelResponse\"\xaa\x06\n\x1c\x43reateInventoryObjectRequest\x12\x1d\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x41\n\x0bobject_type\x18\x02 \x01(\tB,\xfa\x42)r\'R\x02\x64\x62R\x06schemaR\x05tableR\x06\x63olumnR\nsub-column\x12:\n\x02\x64\x62\x18\x03 \x01(\x0b\x32..aa_service.v1.CreateInventoryObjectRequest.Db\x12\x42\n\x06schema\x18\x04 \x01(\x0b\x32\x32.aa_service.v1.CreateInventoryObjectRequest.Schema\x12@\n\x05table\x18\x05 \x01(\x0b\x32\x31.aa_service.v1.CreateInventoryObjectRequest.Table\x12\x42\n\x06\x63olumn\x18\x06 \x01(\x0b\x32\x32.aa_service.v1.CreateInventoryObjectRequest.Column\x12I\n\nsub_column\x18\x07 \x01(\x0b\x32\x35.aa_service.v1.CreateInventoryObjectRequest.SubColumn\x1a\x32\n\x02\x44\x62\x12\x15\n\x04path\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x15\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x1a\x36\n\x06Schema\x12\x15\n\x04path\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x15\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x1a\x35\n\x05Table\x12\x15\n\x04path\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x15\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x1aR\n\x06\x43olumn\x12\x15\n\x04path\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x15\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1a\n\tdata_type\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x1a`\n\tSubColumn\x12\x15\n\x04path\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x15\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12%\n\x08sub_type\x18\x03 \x01(\tB\x13\xfa\x42\x10r\x0eR\x06hstoreR\x04json\"\x1f\n\x1d\x43reateInventoryObjectResponse\"T\n\x1c\x44\x65leteInventoryObjectRequest\x12\x1d\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x15\n\x04path\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\x1f\n\x1d\x44\x65leteInventoryObjectResponse\"<\n\x03Tag\x12\n\n\x02id\x18\x01 \x01(\t\x12\x15\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x12\n\ncreated_at\x18\x03 \x01(\x03\"2\n\x19\x43reateInventoryTagRequest\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"=\n\x1a\x43reateInventoryTagResponse\x12\x1f\n\x03tag\x18\x01 \x01(\x0b\x32\x12.aa_service.v1.Tag\"\x19\n\x17GetInventoryTagsRequest\"<\n\x18GetInventoryTagsResponse\x12 \n\x04tags\x18\x01 \x03(\x0b\x32\x12.aa_service.v1.Tag\"f\n UpdateInventoryObjectTagsRequest\x12\x1d\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x15\n\x04path\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x0c\n\x04tags\x18\x03 \x03(\t\"\xac\x03\n!UpdateInventoryObjectTagsResponse\x12P\n\x06object\x18\x01 \x01(\x0b\x32@.aa_service.v1.UpdateInventoryObjectTagsResponse.InventoryObject\x1a\xb4\x02\n\x0fInventoryObject\x12\x14\n\x0c\x64\x61tastore_id\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x0f\n\x07\x64\x62_path\x18\x04 \x01(\t\x12\x12\n\ntable_path\x18\x05 \x01(\t\x12\x13\n\x0bschema_path\x18\x06 \x01(\t\x12\x1e\n\x16table_attribute_number\x18\x07 \x01(\x04\x12\x11\n\tdata_type\x18\x08 \x01(\t\x12\x12\n\ndata_label\x18\t \x01(\t\x12\x12\n\nupdated_at\x18\n \x01(\x03\x12\x12\n\ncreated_at\x18\x0b \x01(\x03\x12\x17\n\x0f\x64\x61ta_store_name\x18\x0c \x01(\t\x12\x0c\n\x04name\x18\r \x01(\t\x12\x11\n\tvalidated\x18\x0e \x01(\x08\x12\x0c\n\x04tags\x18\x0f \x03(\t\"0\n\x19\x44\x65leteInventoryTagRequest\x12\x13\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\">\n\x1a\x44\x65leteInventoryTagResponse\x12 \n\x04tags\x18\x01 \x03(\x0b\x32\x12.aa_service.v1.Tag2\x96\t\n\x0f\x41\x64minApiService\x12}\n\x18GetInventoryHierarchical\x12..aa_service.v1.GetInventoryHierarchicalRequest\x1a/.aa_service.v1.GetInventoryHierarchicalResponse\"\x00\x12\x65\n\x10GetInventoryFlat\x12&.aa_service.v1.GetInventoryFlatRequest\x1a\'.aa_service.v1.GetInventoryFlatResponse\"\x00\x12w\n\x16UpdateColumnLockStatus\x12,.aa_service.v1.UpdateColumnLockStatusRequest\x1a-.aa_service.v1.UpdateColumnLockStatusResponse\"\x00\x12t\n\x15UpdateColumnDataLabel\x12+.aa_service.v1.UpdateColumnDataLabelRequest\x1a,.aa_service.v1.UpdateColumnDataLabelResponse\"\x00\x12t\n\x15\x43reateInventoryObject\x12+.aa_service.v1.CreateInventoryObjectRequest\x1a,.aa_service.v1.CreateInventoryObjectResponse\"\x00\x12t\n\x15\x44\x65leteInventoryObject\x12+.aa_service.v1.DeleteInventoryObjectRequest\x1a,.aa_service.v1.DeleteInventoryObjectResponse\"\x00\x12k\n\x12\x43reateInventoryTag\x12(.aa_service.v1.CreateInventoryTagRequest\x1a).aa_service.v1.CreateInventoryTagResponse\"\x00\x12\x65\n\x10GetInventoryTags\x12&.aa_service.v1.GetInventoryTagsRequest\x1a\'.aa_service.v1.GetInventoryTagsResponse\"\x00\x12\x80\x01\n\x19UpdateInventoryObjectTags\x12/.aa_service.v1.UpdateInventoryObjectTagsRequest\x1a\x30.aa_service.v1.UpdateInventoryObjectTagsResponse\"\x00\x12k\n\x12\x44\x65leteInventoryTag\x12(.aa_service.v1.DeleteInventoryTagRequest\x1a).aa_service.v1.DeleteInventoryTagResponse\"\x00\x42TZRgithub.com/formalco/control-plane/backend/admin-api/gen/aa_service/v1;aa_servicev1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aa_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZRgithub.com/formalco/control-plane/backend/admin-api/gen/aa_service/v1;aa_servicev1'
  _UPDATECOLUMNLOCKSTATUSREQUEST.fields_by_name['datastore_id']._options = None
  _UPDATECOLUMNLOCKSTATUSREQUEST.fields_by_name['datastore_id']._serialized_options = b'\372B\004r\002\020\001'
  _UPDATECOLUMNLOCKSTATUSREQUEST.fields_by_name['path']._options = None
  _UPDATECOLUMNLOCKSTATUSREQUEST.fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _UPDATECOLUMNDATALABELREQUEST.fields_by_name['datastore_id']._options = None
  _UPDATECOLUMNDATALABELREQUEST.fields_by_name['datastore_id']._serialized_options = b'\372B\004r\002\020\001'
  _UPDATECOLUMNDATALABELREQUEST.fields_by_name['path']._options = None
  _UPDATECOLUMNDATALABELREQUEST.fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEINVENTORYOBJECTREQUEST_DB.fields_by_name['path']._options = None
  _CREATEINVENTORYOBJECTREQUEST_DB.fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEINVENTORYOBJECTREQUEST_DB.fields_by_name['name']._options = None
  _CREATEINVENTORYOBJECTREQUEST_DB.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEINVENTORYOBJECTREQUEST_SCHEMA.fields_by_name['path']._options = None
  _CREATEINVENTORYOBJECTREQUEST_SCHEMA.fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEINVENTORYOBJECTREQUEST_SCHEMA.fields_by_name['name']._options = None
  _CREATEINVENTORYOBJECTREQUEST_SCHEMA.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEINVENTORYOBJECTREQUEST_TABLE.fields_by_name['path']._options = None
  _CREATEINVENTORYOBJECTREQUEST_TABLE.fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEINVENTORYOBJECTREQUEST_TABLE.fields_by_name['name']._options = None
  _CREATEINVENTORYOBJECTREQUEST_TABLE.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEINVENTORYOBJECTREQUEST_COLUMN.fields_by_name['path']._options = None
  _CREATEINVENTORYOBJECTREQUEST_COLUMN.fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEINVENTORYOBJECTREQUEST_COLUMN.fields_by_name['name']._options = None
  _CREATEINVENTORYOBJECTREQUEST_COLUMN.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEINVENTORYOBJECTREQUEST_COLUMN.fields_by_name['data_type']._options = None
  _CREATEINVENTORYOBJECTREQUEST_COLUMN.fields_by_name['data_type']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEINVENTORYOBJECTREQUEST_SUBCOLUMN.fields_by_name['path']._options = None
  _CREATEINVENTORYOBJECTREQUEST_SUBCOLUMN.fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEINVENTORYOBJECTREQUEST_SUBCOLUMN.fields_by_name['name']._options = None
  _CREATEINVENTORYOBJECTREQUEST_SUBCOLUMN.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEINVENTORYOBJECTREQUEST_SUBCOLUMN.fields_by_name['sub_type']._options = None
  _CREATEINVENTORYOBJECTREQUEST_SUBCOLUMN.fields_by_name['sub_type']._serialized_options = b'\372B\020r\016R\006hstoreR\004json'
  _CREATEINVENTORYOBJECTREQUEST.fields_by_name['datastore_id']._options = None
  _CREATEINVENTORYOBJECTREQUEST.fields_by_name['datastore_id']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEINVENTORYOBJECTREQUEST.fields_by_name['object_type']._options = None
  _CREATEINVENTORYOBJECTREQUEST.fields_by_name['object_type']._serialized_options = b'\372B)r\'R\002dbR\006schemaR\005tableR\006columnR\nsub-column'
  _DELETEINVENTORYOBJECTREQUEST.fields_by_name['datastore_id']._options = None
  _DELETEINVENTORYOBJECTREQUEST.fields_by_name['datastore_id']._serialized_options = b'\372B\004r\002\020\001'
  _DELETEINVENTORYOBJECTREQUEST.fields_by_name['path']._options = None
  _DELETEINVENTORYOBJECTREQUEST.fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _TAG.fields_by_name['name']._options = None
  _TAG.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEINVENTORYTAGREQUEST.fields_by_name['name']._options = None
  _CREATEINVENTORYTAGREQUEST.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _UPDATEINVENTORYOBJECTTAGSREQUEST.fields_by_name['datastore_id']._options = None
  _UPDATEINVENTORYOBJECTTAGSREQUEST.fields_by_name['datastore_id']._serialized_options = b'\372B\004r\002\020\001'
  _UPDATEINVENTORYOBJECTTAGSREQUEST.fields_by_name['path']._options = None
  _UPDATEINVENTORYOBJECTTAGSREQUEST.fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _DELETEINVENTORYTAGREQUEST.fields_by_name['id']._options = None
  _DELETEINVENTORYTAGREQUEST.fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _EMPTY._serialized_start=63
  _EMPTY._serialized_end=70
  _CHUNK._serialized_start=72
  _CHUNK._serialized_end=94
  _GETINVENTORYHIERARCHICALREQUEST._serialized_start=96
  _GETINVENTORYHIERARCHICALREQUEST._serialized_end=129
  _GETINVENTORYHIERARCHICALRESPONSE._serialized_start=132
  _GETINVENTORYHIERARCHICALRESPONSE._serialized_end=1021
  _GETINVENTORYHIERARCHICALRESPONSE_DATASTORE._serialized_start=246
  _GETINVENTORYHIERARCHICALRESPONSE_DATASTORE._serialized_end=348
  _GETINVENTORYHIERARCHICALRESPONSE_DB._serialized_start=351
  _GETINVENTORYHIERARCHICALRESPONSE_DB._serialized_end=549
  _GETINVENTORYHIERARCHICALRESPONSE_SCHEMA._serialized_start=551
  _GETINVENTORYHIERARCHICALRESPONSE_SCHEMA._serialized_end=675
  _GETINVENTORYHIERARCHICALRESPONSE_TABLE._serialized_start=678
  _GETINVENTORYHIERARCHICALRESPONSE_TABLE._serialized_end=824
  _GETINVENTORYHIERARCHICALRESPONSE_COLUMN._serialized_start=827
  _GETINVENTORYHIERARCHICALRESPONSE_COLUMN._serialized_end=959
  _GETINVENTORYHIERARCHICALRESPONSE_SUBCOLUMN._serialized_start=961
  _GETINVENTORYHIERARCHICALRESPONSE_SUBCOLUMN._serialized_end=1021
  _GETINVENTORYFLATREQUEST._serialized_start=1023
  _GETINVENTORYFLATREQUEST._serialized_end=1048
  _GETINVENTORYFLATRESPONSE._serialized_start=1051
  _GETINVENTORYFLATRESPONSE._serialized_end=1458
  _GETINVENTORYFLATRESPONSE_COLUMN._serialized_start=1147
  _GETINVENTORYFLATRESPONSE_COLUMN._serialized_end=1458
  _UPDATECOLUMNLOCKSTATUSREQUEST._serialized_start=1460
  _UPDATECOLUMNLOCKSTATUSREQUEST._serialized_end=1564
  _UPDATECOLUMNLOCKSTATUSRESPONSE._serialized_start=1566
  _UPDATECOLUMNLOCKSTATUSRESPONSE._serialized_end=1598
  _UPDATECOLUMNDATALABELREQUEST._serialized_start=1600
  _UPDATECOLUMNDATALABELREQUEST._serialized_end=1704
  _UPDATECOLUMNDATALABELRESPONSE._serialized_start=1706
  _UPDATECOLUMNDATALABELRESPONSE._serialized_end=1737
  _CREATEINVENTORYOBJECTREQUEST._serialized_start=1740
  _CREATEINVENTORYOBJECTREQUEST._serialized_end=2550
  _CREATEINVENTORYOBJECTREQUEST_DB._serialized_start=2207
  _CREATEINVENTORYOBJECTREQUEST_DB._serialized_end=2257
  _CREATEINVENTORYOBJECTREQUEST_SCHEMA._serialized_start=2259
  _CREATEINVENTORYOBJECTREQUEST_SCHEMA._serialized_end=2313
  _CREATEINVENTORYOBJECTREQUEST_TABLE._serialized_start=2315
  _CREATEINVENTORYOBJECTREQUEST_TABLE._serialized_end=2368
  _CREATEINVENTORYOBJECTREQUEST_COLUMN._serialized_start=2370
  _CREATEINVENTORYOBJECTREQUEST_COLUMN._serialized_end=2452
  _CREATEINVENTORYOBJECTREQUEST_SUBCOLUMN._serialized_start=2454
  _CREATEINVENTORYOBJECTREQUEST_SUBCOLUMN._serialized_end=2550
  _CREATEINVENTORYOBJECTRESPONSE._serialized_start=2552
  _CREATEINVENTORYOBJECTRESPONSE._serialized_end=2583
  _DELETEINVENTORYOBJECTREQUEST._serialized_start=2585
  _DELETEINVENTORYOBJECTREQUEST._serialized_end=2669
  _DELETEINVENTORYOBJECTRESPONSE._serialized_start=2671
  _DELETEINVENTORYOBJECTRESPONSE._serialized_end=2702
  _TAG._serialized_start=2704
  _TAG._serialized_end=2764
  _CREATEINVENTORYTAGREQUEST._serialized_start=2766
  _CREATEINVENTORYTAGREQUEST._serialized_end=2816
  _CREATEINVENTORYTAGRESPONSE._serialized_start=2818
  _CREATEINVENTORYTAGRESPONSE._serialized_end=2879
  _GETINVENTORYTAGSREQUEST._serialized_start=2881
  _GETINVENTORYTAGSREQUEST._serialized_end=2906
  _GETINVENTORYTAGSRESPONSE._serialized_start=2908
  _GETINVENTORYTAGSRESPONSE._serialized_end=2968
  _UPDATEINVENTORYOBJECTTAGSREQUEST._serialized_start=2970
  _UPDATEINVENTORYOBJECTTAGSREQUEST._serialized_end=3072
  _UPDATEINVENTORYOBJECTTAGSRESPONSE._serialized_start=3075
  _UPDATEINVENTORYOBJECTTAGSRESPONSE._serialized_end=3503
  _UPDATEINVENTORYOBJECTTAGSRESPONSE_INVENTORYOBJECT._serialized_start=3195
  _UPDATEINVENTORYOBJECTTAGSRESPONSE_INVENTORYOBJECT._serialized_end=3503
  _DELETEINVENTORYTAGREQUEST._serialized_start=3505
  _DELETEINVENTORYTAGREQUEST._serialized_end=3553
  _DELETEINVENTORYTAGRESPONSE._serialized_start=3555
  _DELETEINVENTORYTAGRESPONSE._serialized_end=3617
  _ADMINAPISERVICE._serialized_start=3620
  _ADMINAPISERVICE._serialized_end=4794
# @@protoc_insertion_point(module_scope)
